# For the purpose of using ggplot() with geom_stars()
# Step 1: Obtain the geometry of June.4dates
st_geometry(June.4dates) -> June.4dates.geom
xy <- do.call(rbind, June.4dates.geom) %>% as_tibble() %>% setNames(c("x","y"))
x <- xy$x
y <- xy$y
t = as.Date("2020-06-01") + seq(0, 30, by=8)
# Step 2: Convert stars object into an array and add x and y columns to it
# Then, convert in dataframe and reorder columns to have x and y as first two
June.4dates %>% pull(1) -> June.4dates.arr
June.4dates.arr <- cbind(June.4dates.arr,x,y)
June.4dates.df <- data.frame(June.4dates.arr)
June.4dates.df[,c(5,6,1:4)] -> June.4dates.df
# Step 3: rebuild stars object
June.4dates.new <- st_as_stars(June.4dates.df,dims=c("x","y"))
merge(June.4dates.new) -> June.4dates.new
setNames(June.4dates.new,"Tmax.pred") -> June.4dates.new
June.4dates.new = st_set_dimensions(June.4dates.new, names=c("x","y","time"))
June.4dates.new = st_set_dimensions(June.4dates.new, "time", values = t, names = "time", point = TRUE)

# Plot results

ggplot() + geom_stars(data = June.4dates.new) +
    coord_equal() +
    facet_wrap(~time) +
    theme_void() +
    scale_fill_steps(n.breaks=8,low="blue",high="orange",na.value="grey95") +
    scale_x_discrete(expand=c(0,0))+
    scale_y_discrete(expand=c(0,0))+
    labs(fill="Pred") +
    theme(panel.border = element_rect(linetype = "solid", fill = NA),
        legend.key.size = unit(0.95, 'cm'))+
    theme(plot.margin=unit(c(1,1,1,1),"cm"))

