library(GA)
# sample semivariogram
x <- MX[1,] # spacelag
y <- MY[,1] # timelag
z <- GG # gamma value

# fitness function
zeta <-  function(crom){
  crom <- matrix(crom, ncol = 7)
  n_s <- crom[,1]
  s_s <- crom[,2]
  a_s <- crom[,3]
  n_t <- crom[,4]
  s_t <- crom[,5]
  a_t <- crom[,6]
  S_st <- crom[,7]
  
  g = 0;
  for (i in 1:31){
    gamma_s <- n_s + s_s*x[i]/a_s
    for (j in 1:10){
      gamma_t <- n_t + s_t*(1-exp(-y[j]/a_t))
      z.fit <- S_st*(gamma_s+gamma_t-gamma_s*gamma_t)
      Diff <- (z[j,i]-z.fit)
      if (!is.na(Diff)){
        g <- g + Diff^2
      }
    }
  }
  return (1/g)
}

# GA solution
pop.size<- 30
max.gen <- 1000
xover.prob <- 0.7
mut.prob <- 0.1

# seed = 246 for reproducibility with the book results
# it should be removed in a real-world analysis
GA <- ga(type = "real-valued", fitness = zeta, 
         lower = c(0,1,1e4,0,0,100,100),
         upper = c(0.05,2,1e5,0.05,2,2000,1000),
         maxiter=max.gen,popSize = pop.size,seed=246)

(solution <- unname(GA@solution))

# Post processing
n_s <- solution[1]
s_s <- solution[2]
a_s <- solution[3]
n_t <- solution[4]
s_t <- solution[5]
a_t <- solution[6]
S_st <- solution[7]

gam_t = n_t+s_t*(1-exp(-MY/a_t))
gam_s = n_s+s_s*MX/a_s
gam_st = S_st*(gam_s+gam_t-gam_s*gam_t)

# plot the solution
levelplot(gam_st ~ MX + MY,col.regions=heat.colors,xlab="distance",ylab="time lag")
# difference between sample and model semivariogram
D <- abs(gam_st-GG)
# plot the error
levelplot(abs(D) ~ MX + MY,col.regions=heat.colors,xlab="distance",ylab="time lag")
# Sum of squared differences
(SSD <- sum(D^2))

