# Load libraries
library(gstat)
library(sf)
library(reshape)
library(lattice)

# First part: generation of artificial data
# Generate Gaussian surface Z(X,Y) with added noise on a grid
X <- seq(0,10,0.1)
Y <- seq(0,10,0.1)
N <- length(X)
Noise <- matrix(rnorm(N*N,mean=0,sd=0.4),ncol=N)
exp(-(X-5)^2) -> eX
exp(-(Y-3)^2) -> eY
# create data matrix Z
Z <- 10*eX %*% t(eY)
Z <- Z+Noise
grid <- expand.grid(X=X, Y=Y)
levelplot(Z~X*Y,grid)

# Second part: semivariogram computation
# Convert Z to dataframe
Z.df <- melt(Z)
names(Z.df) <- c("X","Y","Z")
Z.df$X <- Z.df$X-1
Z.df$Y <- Z.df$Y-1
# Convert dataframe to sf class
Z.sf <- st_as_sf(Z.df,coords=c("X","Y"))
# compute empirical semivariogram
vgm <- variogram(Z~1, Z.sf)
plot(vgm)
# model fitting
vgm.model <- fit.variogram(vgm, vgm(sd(Z)^2, "Gau", sqrt(max(X)^2+max(Y)^2), 0.1))
plot(vgm,vgm.model)
# Plots
plot(vgm$dist,vgm$gamma,ylab="Semivariogram",xlab="Distance")
dmax <- max(vgm$dist)
d <- seq(0,dmax,0.1)
Nugget <- vgm.model$psill[1]
Sill <- vgm.model$psill[2]
Range <- vgm.model$range[2]
Gam <- Nugget+Sill*(1-exp(-d^2/Range^2))
lines(d,Gam,col="blue")
