# Libraries
library(gstat)
library(sf)
library(gstat)
library(sf)
library(reshape)
library(lattice)

# Read data
setwd("C:/RPA/code/spatial_analysis")
geo_data = read.csv("data/20201121_weather.csv")
xy <- geo_data[,c(1,2)]

# Read Emilia-Romagna shapefile and plots station locations
ER.shape <- st_read("data/RER.shp", quiet=TRUE)
plot(ER.shape$geometry)
points(xy,pch=17,col="red",cex=0.5)

# Semivariogram cloud
Tmax.vgm.cloud <- variogram(Tmax ~ 1, locations = ~UTM.X + UTM.Y, data = geo_data, cloud=TRUE)
plot(Tmax.vgm.cloud)

# Convert dataframe geo_data into object of the sf class
geo_data.sf <- st_as_sf(geo_data,coords=c("UTM.X","UTM.Y"),crs="EPSG:32632")
vgm <- variogram(Tmax~1,geo_data.sf)
plot(vgm)

# Anisotropy
vgm.aniso <- variogram(Tmax~1,geo_data.sf, alpha = c(0, 45, 90, 135))
plot(vgm.aniso)

# Linear dependence
Tmax.fit <- lm(Tmax~Alt,data=geo_data) 
plot(Tmax~Alt,geo_data,xlab="Altitude (m)",ylab=expression(paste(T[max])))
abline(Tmax.fit,col="red")

# Work on residuals of linear model
# Semivariogram cloud
Tmax.res <- Tmax.fit$residuals
Tmax.vgm.cloud <- variogram(Tmax.res~1,locations = ~UTM.X + UTM.Y, data = geo_data, cloud=TRUE)
plot(Tmax.vgm.cloud)
# Empirical semivariogram of residuals
Tmax.vgm <- variogram(Tmax.res~1,locations = ~UTM.X + UTM.Y, data = geo_data)
plot(Tmax.vgm)
Tmax.vgm.model <- vgm(0.2, "Lin", 150000, 0.5)
plot(Tmax.vgm,Tmax.vgm.model)
