# Load the stars package
library(stars)
# import DEM data of Emillia-Romagna
setwd("C:/RPA/code/spatial_analysis")
ER.DEM <- read_stars("data/dem450_ER.tif")
# give the name Alt to the data column
names(ER.DEM) <- 'Alt'
# Set the CRS
st_crs(ER.DEM) <- st_crs(geo_data.sf)
# Show Altitude map
ggplot() + geom_stars(data = ER.DEM) +
  coord_equal()+
  theme_void() +
  scale_fill_steps(n.breaks=8,low="lightyellow2",high="red",na.value="white") +
  scale_x_discrete(expand=c(0,0))+
  scale_y_discrete(expand=c(0,0))+
  labs(fill="Alt") +
  theme(panel.border = element_rect(linetype = "solid", fill = NA),
        legend.key.size = unit(0.95, 'cm'))+
  theme(plot.margin=unit(c(1,1,1,1),"cm"))

# Kriging
res.kriged <- krige(Tmax.res~1,geo_data.sf,ER.DEM,model=Tmax.vgm.model) 
# show kriging results (predicted residuals)
ggplot() + geom_stars(data = res.kriged) +
  coord_equal()+
  theme_void() +
  scale_fill_steps(n.breaks=8,low="blue",high="orange",na.value="white") +
  scale_x_discrete(expand=c(0,0))+
  scale_y_discrete(expand=c(0,0))+
  labs(fill="Pred") +
  theme(panel.border = element_rect(linetype = "solid", fill = NA),
        legend.key.size = unit(0.95, 'cm'))+
  theme(plot.margin=unit(c(1,1,1,1),"cm"))
