# required libraries
library(stars)
library(zoo)
library(xts)
library(mapview)
setwd("C:/RPA/code/spatial_analysis")
# Read maximum daily temperatures in years 2019-2020 and station coordinates
Tmax_data <- read.csv("ER_Tmax_2019-2020.csv",h=TRUE,check.names = FALSE)
# Read info about measuremente stations
Stations <- read.csv("ER_stations.csv",h=TRUE)
cod.station <- names(Tmax_data)
cod.station[-1] -> cod.station
subset(Stations,Stations$ID_station%in%cod.station) -> Stations.sel
# Convert into a stars object:
# Step 1: Read in a zoo object
Tmax.zoo <- read.zoo(Tmax_data,index.column=1,format = "%d/%m/%Y")
str(Tmax.zoo)
# Step 2: Convert into an xts (time series)
xts(Tmax.zoo) -> Tmax.xts
str(Tmax.xts)
# Step 3: select stations having Tmax measurement, and obtain geometry
Stations.dat <- subset(Stations.sel,select=c("ID_station","Altitude","UTM_X","UTM_Y"))
space_part <- st_as_sf(Stations.dat,coords=c("UTM_X","UTM_Y"),crs = "EPSG:32632")
# Show measurement stations
space_part.geom <- st_geometry(space_part)
mapview(space_part.geom)
# Step 4: add Altitude data from file Stations
tmp <- subset(Stations.sel,select=c("ID_station","Altitude"))
Alt_data <- Tmax_data
nnn <- as.character(tmp$ID_station)
for (i in 1:length(nnn))
  Alt_data[nnn[i]] <- tmp$Altitude[i]
# Read altitudesa in a zoo object
Alt.zoo <- read.zoo(Alt_data,index.column=1,format = "%d/%m/%Y")
# Convert altitudes into xts
xts(Alt.zoo) -> Alt.xts
# Step 5: Make a stars object having two attributes: TMAX and ALT
st_as_stars(list(TMAX = as.matrix(Tmax.xts),ALT = as.matrix(Alt.xts))) %>%
  st_set_dimensions(names = c("time", "station")) %>%  # nomi colonne
  st_set_dimensions("time", index(Tmax.xts)) %>%  # trasforma time da char a POSIXct
  st_set_dimensions("station", space_part.geom) -> dat1.st

# Verify object
class(dat1.st)
dat1.st









